@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import copy
-
+import logging
 from crispy_forms.layout import Layout, Fieldset, Submit, Button, Field
 from crispy_forms.bootstrap import Accordion, AccordionGroup
 from crispy_forms.helper import FormHelper
@@ -19,7 +19,7 @@ from django.forms import ModelMultipleChoiceField, ModelChoiceField, HiddenInput
 from django.urls import reverse
 from django import forms
 
-from apis_core.apis_metainfo.models import TempEntityClass
+from apis_core.apis_metainfo.models import TempEntityClass, Text, Uri, Collection
 from apis_core.apis_relations.forms2 import validate_target_autocomplete
 from apis_core.apis_relations.models import AbstractRelation
 from apis_core.apis_vocabularies.models import VocabsBaseClass, AbstractRelationType
@@ -29,13 +29,14 @@ from apis_import_project.tables import get_generic_relations_table
 if 'apis_highlighter' in settings.INSTALLED_APPS:
     from apis_highlighter.models import Annotation, AnnotationProject
 
-from apis_core.apis_metainfo.models import Text, Uri, Collection
 from apis_core.helper_functions import DateParser
 from apis_core.helper_functions.RDFParser import RDFParser
 from apis_core.apis_entities.fields import ListSelect2, Select2Multiple
 from apis_core.apis_entities.models import AbstractEntity
 from .models import DataSource, ImportProject
 
+log = logging.getLogger("mylogger")
+log.setLevel(logging.WARNING)
 
 class EditDataSourceForm(forms.ModelForm):
     class Meta:
@@ -93,7 +94,7 @@ class CreateImportProjectForm(forms.ModelForm):
 
 class UploadFileForm(forms.Form):
     """
-    Combines to models:
+    Combines two models:
     names, citation and year are fields in DataSource
     file is processed and then split into DataSourcePageObjects
     """
@@ -114,6 +115,8 @@ class UploadFileForm(forms.Form):
 
 
 def get_custom_generic_entities_form(entity):
+    # fixme: __maintainence__ __gpirgie__ Hook up with existing apis core function/class if possible
+
     class CustomGenericEntitiesForm(forms.ModelForm):
         class Meta:
             model = AbstractEntity.get_entity_class_of_name(entity)
@@ -130,7 +133,6 @@ def get_custom_generic_entities_form(entity):
                 "text",
                 "source",
                 "published",
-                # "review", # note: excluded review as not needed in viecpro
             ]
             exclude.extend(model.get_related_entity_field_names())
             exclude.extend(model.get_related_relationtype_field_names())
@@ -338,13 +340,17 @@ def get_custom_generic_entities_form(entity):
     return CustomGenericEntitiesForm
 
 
+
 class GenericEntitiesStanbolForm(forms.Form):
+    # fixme: __maintainence__ __gpirgie__ Hook up with existing apis core function/class if possible
+
     def save(self, *args, **kwargs):
         cd = self.cleaned_data
         entity = RDFParser(cd["entity"], self.entity.title()).get_or_create()
         return entity
 
     def __init__(self, entity, *args, **kwargs):
+
         attrs = {
             "data-placeholder": "Type to get suggestions",
             "data-minimum-input-length": getattr(settings, "APIS_MIN_CHAR", 3),
@@ -357,27 +363,27 @@ class GenericEntitiesStanbolForm(forms.Form):
         self.helper = FormHelper()
         form_kwargs = {"entity": entity}
         url = reverse(
-                "apis:apis_entities:generic_entities_autocomplete",
-                args=[entity.title(), "remove"],
+            "apis:apis_entities:generic_entities_autocomplete",
+            args=[entity.title(), "remove"],
         )
         label = "Create {} from reference resources".format(entity.title())
         button_label = "Create"
         if ent_merge_pk:
             form_kwargs["ent_merge_pk"] = ent_merge_pk
             url = reverse(
-                    "apis:apis_entities:generic_entities_autocomplete",
-                    args=[entity.title()],
+                "apis:apis_entities:generic_entities_autocomplete",
+                args=[entity.title(), ent_merge_pk],
             )
             label = "Search for {0} in reference resources or db".format(entity.title())
             button_label = "Merge"
         self.helper.form_action = reverse(
-                "apis:apis_entities:generic_entities_stanbol_create", kwargs=form_kwargs
+            "apis:apis_entities:generic_entities_stanbol_create", kwargs=form_kwargs
         )
         self.helper.add_input(Submit("submit", button_label))
         self.fields["entity"] = autocomplete.Select2ListCreateChoiceField(
-                label=label,
-                widget=ListSelect2(url=url, attrs=attrs),
-                validators=[URLValidator],
+            label=label,
+            widget=ListSelect2(url=url, attrs=attrs),
+            validators=[URLValidator],
         )
 
 
@@ -424,8 +430,7 @@ def get_generic_vocabs_form(model_name):
             self.helper.add_input(Submit("submit", "save", css_class=f"{model_name}Form"))
             self.helper.form_method = "post"
             self.helper.form_class = "form pdf_tool_itemcreate"
-            self.helper.form_action = reverse("apis_import_project:item_create", kwargs={"model_name": model_name})  #
-            # /apis_import_project/create_item/{model_name}"
+            self.helper.form_action = reverse("apis_import_project:item_create", kwargs={"model_name": model_name})  
             self.helper.layout = Layout(Field("name",
                                               id=f"{model_name}_name_field"))  # NOTE: used to clean the fields in
             # Ajax success function.
@@ -453,7 +458,6 @@ def get_generic_relationtype_form(model_name):
                                         Field("name_reverse", id=f"{model_name}Form_name_reverse_field"))
             self.fields["name_reverse"].required = False
 
-            # f"{reverse('apis_import_project:create_item', kwargs={'model_name', model_name})}"
 
     return GenericRelationTypeForm
 
@@ -481,6 +485,8 @@ def get_generic_entity_type_form(model_name):
 
 
 class CustomGenericRelationForm(forms.ModelForm):
+    # fixme: __maintainence__ __gpirgie__ Hook up with existing apis core function/class if possible
+
     class Meta:
         model = TempEntityClass
         fields = ['start_date_written', 'end_date_written', 'references', 'notes']
@@ -532,8 +538,9 @@ class CustomGenericRelationForm(forms.ModelForm):
                     text=txt,
                     user_added=self.request.user,
                     annotation_project_id=int(self.request.session.get('annotation_project', 1)))
+            a.entity_link = x
             a.save()
-            a.entity_link.add(x)
+        print('saved: {}'.format(x))
         return x
 
     def get_text_id(self):
@@ -685,7 +692,7 @@ class CustomGenericRelationForm(forms.ModelForm):
                     validators=[validate_target_autocomplete],
                     help_text=help_text_target)
         else:
-            pass
+            print('no hit rel_accessor')
         if instance and instance.id:
             self.fields['target'].choices = [
                 (str(Uri.objects.filter(entity=getattr(instance, self.rel_accessor[2]))[0]),
@@ -702,6 +709,9 @@ class CustomGenericRelationForm(forms.ModelForm):
                 self.fields['relation_type'].initial = (instance.relation_type.id, instance.relation_type.label_reverse)
         if highlighter:
             css_notes = 'HL'
+            log.warning("highlighter was true")
+        else:
+            log.warning("highlighter was false")
 
         self.helper.include_media = False
         self.helper.layout = Layout(
