@@ -102,12 +102,6 @@ class DataSource(models.Model):
             page.page_token = page_token
             page.save()
 
-    def delete(self, *args, **kwargs):
-        # todo: write tests for this method
-        for el in DataSourcePage.objects.filter(DataSource=self):
-            el.image.delete()
-            el.thumbnail.delete()
-        super(DataSource, self).delete(*args, **kwargs)
 
     def get_next_page(self, curr_page, direction="next"):
         curr_page = int(curr_page)
