@@ -41,11 +41,12 @@ from .models import DataSourceProjectState, DataSource, ImportProject, PageData,
 from .serializers import EntitySerializer
 from .upload_helper import create_datasource_and_pages, update_datasource_and_pages
 
-if 'apis_highlighter' in settings.INSTALLED_APPS:
-    from apis_core.helper_functions.highlighter import highlight_text
-    from apis_highlighter import forms as highlighter_form_module
+# if 'apis_highlighter' in settings.INSTALLED_APPS:
+#     from apis_core.helper_functions.highlighter import highlight_text
+#     from apis_highlighter import forms as highlighter_form_module
+#
+#     form_module_list.append(highlighter_form_module)
 
-    form_module_list.append(highlighter_form_module)
 
 # NOTE: log level is set in .logger.py. Set level to INFO for stdout-logstreams
 log = logging.getLogger("mylogger")
@@ -95,7 +96,7 @@ def get_json_rel(rel_class=None, rel_id=None, instance=None, version="-"):
 # todo: __feature__ __gpirgie__ consider implementing a seperate searialization, and table for labels; with
 #  labeltype, sdw, edw, and entity.
 def get_json_entity(entity, version="-"):
-    # todo: __gpirgie__ instead of showing all data, it might be more reasonable to change the differences to the
+    # todo: __gpirgie__ instead of showing all data, it might be more reasonable to show the differences to the
     #  last version and display that in the frontend
     apis_serialization = EntitySerializer(entity).data
     # apis_serialization = entity.get_serialization()
@@ -829,7 +830,9 @@ class EditorAllSectionsView(View):
             RequestConfig(request, paginate={"per_page": 1000}).configure(
                     # todo: __refactor__ IMPORTANT __gpirgie__ disabled pagination, as I didn't have the time to
                     #  implement it correctly. For entities with a lot of relations, this causes delaus in loading them.
-                    tb_object)  # changed per_page from 10 to 20 here.
+                        # fixme: __maintainence__ __gpirgie__ implement pagination via ajax
+
+                    tb_object)  
             side_bar.append((title_card, tb_object, ''.join([x.title() for x in match]), tb_object_open))
         form = get_custom_generic_entities_form(entity.title())
         form = form(instance=instance)
@@ -913,6 +916,8 @@ def update_control_section(request):  # todo: __refactor__ __gpirgie__ rename to
 
 @method_decorator(login_required, name='dispatch')
 class GenericEntitiesUpdateView(View):
+    # fixme: __maintainence__ __gpirgie__ Hook up with existing apis core function if possible
+
     def get_html_str(self, *args, **kwargs):
         log.info("CALLED THIS")
 
@@ -977,6 +982,8 @@ class GenericEntitiesUpdateView(View):
 
 @method_decorator(login_required, name='dispatch')
 class GenericEntitiesCreateView(View):
+        # fixme: __maintainence__ __gpirgie__ Hook up with existing apis core function if possible
+
 
     def get_html_str(self, *args, **kwargs):
         entity = kwargs['entity']
@@ -1113,6 +1120,7 @@ class UpdatePageTokenView(View):
 def save_custom_ajax_form(request, entity_type, kind_form, SiteID,
                           ObjectID=False):
     # todo: __refactor__ __gpirgie__ I would only need project_pk and datapage_obj here.
+    # fixme: __maintainence__ __gpirgie__ Hook up with existing apis core function if possible
 
     col_pk = request.session.get("col_pk")
     pagedata_pk = request.session.get("pagedata_pk")
@@ -1282,6 +1290,8 @@ def save_custom_ajax_form(request, entity_type, kind_form, SiteID,
 
 @login_required
 def get_custom_ajax_form(request):
+        # fixme: __maintainence__ __gpirgie__ Hook up with existing apis core function if possible
+
     '''Returns forms rendered in html'''
     FormName = request.POST.get('FormName')
     SiteID = request.POST.get('SiteID')
